@@ -6,7 +6,7 @@
 ;; or any later version published by the Free Software Foundation.  See
 ;; the file COPYING included with the this distribution.
 
-(define len-v
+(define c99-len-v
   #(1 1 1 1 3 1 4 4 3 3 3 2 2 6 7 1 3 1 3 2 1 1 2 2 2 2 4 1 1 1 1 1 1 1 4 1 
     3 3 3 1 3 3 1 3 3 1 3 3 3 3 1 3 3 1 3 1 3 1 3 1 3 1 3 1 5 1 3 1 1 1 1 1 1 
     1 1 1 1 1 1 3 1 5 3 0 1 2 1 2 1 2 1 2 1 3 1 3 1 1 1 1 1 1 1 1 1 1 1 1 1 1 
@@ -17,7 +17,7 @@
     1 2 1 1 2 1 5 7 5 5 7 8 2 1 1 0 1 3 2 2 3 2 1 0 2 1 1 1 1 1 5 1 4 3 1 2 0 
     1 1 1 1 1 1 1 2 1 1 1 1))
 
-(define pat-v
+(define c99-pat-v
   #(((103 . 1) (182 . 2) (97 . -281) (95 . -281) (-1 . -281)) ((22 . 3) (28 
     . 4) (29 . 5) (30 . 6) (31 . 7) (32 . 8) (33 . 9) (34 . 10) (35 . 11) (36 
     . 12) (38 . 13) (37 . 14) (40 . 15) (24 . 16) (25 . 17) (26 . 18) (27 . 19
@@ -766,7 +766,7 @@
     . 201) (113 . 202) (114 . 203) (115 . 204) (116 . 205) (109 . 489)) ((-1 
     . -268)) ((-1 . -265)) ((-1 . -269))))
 
-(define rto-v
+(define c99-rto-v
   #(#f 177 177 177 177 176 176 176 176 176 176 176 176 176 176 175 175 175 
     175 171 171 168 168 168 168 168 168 167 167 167 167 167 167 166 166 165 
     165 165 165 164 164 164 163 163 163 162 162 162 162 162 161 161 161 160 
@@ -785,7 +785,7 @@
     105 105 105 104 104 111 111 111 111 111 182 103 103 102 102 102 102 102 
     102 102 101 101 99 99 151 151 181 181 180 180 180 179 179 98 134 110 100))
 
-(define mtab
+(define c99-mtab
   '((cpp-pragma . 1) (cpp-stmt . 2) ($chlit . 3) ($float . 4) ($fixed . 5) (
     cpp-ident . 6) ($ident . 7) ($string . 8) ("return" . 9) ("break" . 10) (
     "continue" . 11) ("goto" . 12) ("for" . 13) ("do" . 14) ("while" . 15) (
