@@ -1,12 +1,14 @@
 ;; nyacc/lang/Tcpp.scm
 ;;
-;; Copyright (C) 2015,2016 Matthew R. Wette
+;; Copyright (C) 2015-2017 Matthew R. Wette
 ;; 
 ;; Copying and distribution of this file, with or without modification,
 ;; are permitted in any medium without royalty provided the copyright
 ;; notice and this notice are preserved.  This file is offered as-is,
 ;; without any warranty.
 
+(add-to-load-path (string-append (getcwd) "/../../../../module/"))
+
 (use-modules (nyacc lang c99 cppmach))
 (use-modules (nyacc lang c99 cpp))
 (use-modules (nyacc lalr))
@@ -14,20 +16,16 @@
 (use-modules (nyacc lang util))		; move-if-changed
 (use-modules (ice-9 pretty-print))
 
-(when #t
+(when #f
   (gen-cpp-files "../../../../module/nyacc/lang/c99")
   (system "touch ../../../../module/nyacc/lang/c99/cpp.scm"))
 
-(when #f
-  (with-output-to-file "cpplang.txt.new"
+(when #t
+  (with-output-to-file "cpplang.txt"
     (lambda ()
-      (let* ((notice (assq-ref (assq-ref cpp-spec 'attr) 'notice))
-	     (lines (if notice (string-split notice #\newline) '())))
-	(for-each (lambda (l) (simple-format #t "  ~A\n" l)) lines)
-	(newline))
       (pp-lalr-grammar cpp-spec)
-      (pp-lalr-machine cpp-mach)))
-  (move-if-changed "cpplang.txt.new" "cpplang.txt")
+      (pp-lalr-machine cpp-mach)
+      #;(system "zip lang.txt")))
   #t)
 
 (when #f
@@ -39,5 +37,4 @@
     (simple-format #t "=> ~S\n" (eval-cpp-expr sx dt))
     #f))
 
-
 ;; --- last line ---
